.. py:currentmodule:: lsst.resources

.. _lsst.resources:

##############
lsst.resources
##############

Changes
=======

.. toctree::
   :maxdepth: 1

   CHANGES.rst


.. _lsst.resources-dev:

Design and Development
======================

``lsst.resources`` is developed at https://github.com/lsst/resources.

It is available from PyPI as ``lsst-resources``: https://pypi.org/project/lsst-resources/

Configuration
=============

.. toctree::
   s3.rst

.. _lsst.resources-pyapi:

Python API reference
====================

.. automodapi:: lsst.resources
   :no-main-docstr:


See also :ref:`lsst.resources-internal-api`.

.. toctree::
   :hidden:

   internal-api.rst
